@@ -27,6 +27,8 @@
 #include "latexila-types.h"
 #include "latexila-enum-types.h"
 
+#include "latexila-app.h"
+#include "latexila-buffer.h"
 #include "latexila-build-job.h"
 #include "latexila-build-tool.h"
 #include "latexila-build-tools.h"
@@ -34,6 +36,7 @@
 #include "latexila-build-tools-personal.h"
 #include "latexila-build-view.h"
 #include "latexila-factory.h"
+#include "latexila-init.h"
 #include "latexila-latex-commands.h"
 #include "latexila-post-processor.h"
 #include "latexila-post-processor-all-output.h"
